#!/bin/sh
#---------------------------------------------------------------------
#     Copyright (C) GFD Dennou Club, 2000-2005. All rights reserved.
#---------------------------------------------------------------------
#= Generate shell script "gt4frt".
#
#   * Developers: Eizi TOYODA (toyoda), Yasuhiro MORIKAWA (morikawa)
#   * Version: $Id: gt4frtgen.sh,v 1.2 2005/09/04 12:19:54 morikawa Exp $
#   * Tag Name: $Name: gt4f90io-20060121-3 $
#   * Change History: 
#

fc="`which ${FC:?}`"
linker="$LINKF"
mods="-I${MODINSTDIR:?}"
fflags="${SYSFFLAGS}"
libs="-L${LIBINSTDIR:?} -l${LIBNAME:?}"

ldflags=${SYSLDFLAGS}
ldlibs=${SYSLDLIBS:?}
out=${1:-gt4frt}

if [ ${F90MODTYPE:?} = intel.d ]; then
	ldlibs=`echo $ldlibs | sed s/-lm//`
fi

cat > $out <<EOF
#!/bin/sh

fc="$fc"
linker="$linker"
mods="$mods"
fflags="$fflags"
libs="$libs"
ldflags="$ldflags"
ldlibs="$ldlibs"

EOF

if [ ${F90MODTYPE:?} = intel.d ]; then

	cat >> $out <<EOF
# support for Intel Fortran
	if [ ! -f work.pcl ]; then
		echo work.pc > work.pcl
	fi
	for arg in \$mods
	do
	    case "\$arg" in
	    -I*)
		dir=\`echo \$arg | sed s/-I//\`
		if [ ! -f \$dir/work.pc ]; then
			echo Notice: \$dir/work.pc not exist, and ignored.
			touch work.pcl
			break
		fi
		if ! grep -q "^\$dir/work.pc\\$" work.pcl
		then
			echo adding \$dir
			echo \$dir/work.pc >> work.pcl
		fi
		;;
	    esac
	done
EOF

fi

LINKF_HEAD=`echo "$LINKF" | sed s'/ .*//'`
if [ X"$LINKF_HEAD" = X"$FC" ]; then
    linker_is_not_fortran=0
else
    linker_is_not_fortran=1
fi

if [ $linker_is_not_fortran = 0 ]; then
    cat >> $out <<EOF

echo \$fc \$fflags \$mods "\$@" \$libs \$ldflags \$ldlibs
exec \$fc \$fflags \$mods "\$@" \$libs \$ldflags \$ldlibs
EOF

else
    cat >> $out <<EOF

allopts=
outputflag=0
outputfile=
srcfile=
for opt in "\$@"
do
	if [ \$outputflag = 1 ]; then
		outputfile=\$opt
		outputflag=0
		continue
	fi
	if [ \$opt = "-o" ]; then
		outputflag=1
		continue
	fi
	case "\$opt" in
	    *?.f90|*?.f|*?.F90|*?.F)
		srcfile="\$opt"
#		srcbase=\`echo \$opt | sed 's/\.[\.]*$//'\`
		continue
		;;
	esac
	allopts="\$allopts \$opt"
done

if test X"\$srcfile" = X""; then
	echo "\`basename \$0\`: Error: Specify fortran source file with suffix *.f90|*.f|*.F90|*.F"
	exit 1
fi

if test X"\$outputfile" = X""; then
	outputfile=a.out
fi
#echo \$srcfile
#echo \$srcbase
#echo \$outputfile
#echo \$allopts
#
#exit

echo \$fc \$fflags \$mods -c \$srcfile -o \$srcfile.o \$allopts
\$fc \$fflags \$mods -c \$srcfile -o \$srcfile.o \$allopts || exit 1

echo \$linker \$mods \$allopts \$srcfile.o -o \$outputfile \$libs \$ldflags \$ldlibs
\$linker \$mods \$allopts \$srcfile.o -o \$outputfile \$libs \$ldflags \$ldlibs  || exit 1

echo rm \$srcfile.o
rm \$srcfile.o  || exit 1
EOF

fi